![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xoa-utils) [![PyPI](https://img.shields.io/pypi/v/xoa-utils)](https://pypi.python.org/pypi/xoa-utils) ![GitHub](https://img.shields.io/github/license/xenanetworks/open-automation-utilities) [![Documentation Status](https://readthedocs.org/projects/xena-openautomation-utilities/badge/?version=stable)](https://xena-openautomation-utilities.readthedocs.io/en/stable/?badge=stable)

# Xena OpenAutomation Utilities

Xena OpenAutomation Utilities (XOA ANLT Utility) provides an **interactive shell** for users to control Xena testers via **command-line interface** (CLI) commands to performance operations such as ANLT testing and resource management in an interactive fashion.

## Installation
See [installation guide](https://docs.xenanetworks.com/projects/xoa-utilities/en/stable/getting_started/installation.html)

## Step-by-Step Guide

See [step-by-step guide](https://docs.xenanetworks.com/projects/xoa-utilities/en/stable/getting_started/step_by_step.html)
